@@ -110,10 +110,14 @@ def create_handler(app):
         """Handler to give to lambda... which wraps FastAPI"""
         if event.get("source") in ["aws.events", "serverless-plugin-warmup"]:
             print("Lambda is warm, now!!!")
+            context.serverless_sdk.set_endpoint('/warmup')
             return {}
         print('context', context)
         print('contect_dict', context.__dict__)
         print('sls sdk', context.serverless_sdk)
+
+        print("EVENTD", event)
+
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
         response = asgi_handler(event, context)
         print('response', response)
